@@ -350,6 +350,7 @@ mpv_handle *MpvProxy::mpv_init()
         QFileInfo jmfi("/dev/jmgpu"); //jmgpu
         QFileInfo X100GPU("/dev/x100gpu");
         QFileInfo X100VPU("/dev/vxd0");
+        QFileInfo mtfi("/dev/mtgpu.0");
         if (fi.exists() || jmfi.exists()) { //2.1.1景嘉微
             QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
             QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
@@ -395,7 +396,7 @@ mpv_handle *MpvProxy::mpv_init()
             qInfo() << "修改音视频同步模式";
             my_set_property(pHandle, "video-sync", "desync");
         }
-        if (!fi.exists() && !jmfi.exists()) {
+        if (!fi.exists() && !jmfi.exists() && !mtfi.exists()) {
             my_set_property(pHandle, "vo", "x11");
             m_sInitVo = "x11";
         }
@@ -451,6 +452,12 @@ mpv_handle *MpvProxy::mpv_init()
         } else {
             my_set_property(pHandle, "hwdec", "auto");
         }
+
+#if defined (__sw_64__)
+        //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
+        my_set_property(pHandle, "vo", "gpu,x11");
+        m_sInitVo = "gpu,x11";
+#endif
     }
 
     if (composited) {
@@ -732,6 +739,7 @@ void MpvProxy::handle_mpv_events()
             qInfo() << QString("rotate metadata: dec %1, out %2")
                     .arg(my_get_property(m_handle, "video-dec-params/rotate").toInt())
                     .arg(my_get_property(m_handle, "video-params/rotate").toInt());
+            m_bLoadMedia = false;
             break;
         }
         case MPV_EVENT_VIDEO_RECONFIG: {
@@ -751,6 +759,7 @@ void MpvProxy::handle_mpv_events()
                     "reason " << ev_ef->reason;
 
             setState(PlayState::Stopped);
+            m_bLoadMedia = false;
             break;
         }
 
@@ -1229,6 +1238,7 @@ void MpvProxy::initMember()
     m_bPendingSeek = false;
     m_bPolling = false;
     m_bConnectStateChange = false;
+    m_bLoadMedia = false;
     m_bPauseOnStart = false;
     m_bIsJingJia = false;
     m_bInited = false;
@@ -1260,11 +1270,18 @@ void MpvProxy::initMember()
 
 void MpvProxy::play()
 {
+    if(m_bLoadMedia) {
+        QTimer::singleShot(5000, [=](){ //超时5s恢复状态，视频加载成功后也会重置状态，正常播放状态下不会进入此函数
+            m_bLoadMedia = false;
+        });
+        return;
+    }
     bool bRawFormat = false;
     QList<QVariant> listArgs = { "loadfile" };
     QStringList listOpts = { };
     PlayerEngine* pEngine = nullptr;
     bool bAudio = false;
+    m_bLoadMedia = true;
 
     if (!m_bInited) {
         firstInit();
