@@ -68,7 +68,24 @@ public:
      * @brief TooltipHandler 构造函数
      * @param parent 父窗口
      */
-    explicit Platform_TooltipHandler(QObject *parent): QObject(parent) {}
+    explicit Platform_TooltipHandler(QObject *parent): QObject(parent) {
+        connect(&m_showTime, &QTimer::timeout, [=]{
+            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
+            if (m_object != nullptr) {
+                auto tip = m_object->property("HintWidget").value<Tip *>();
+                auto btn = tip->property("for").value<QWidget *>();
+                tip->setText(btn->toolTip());
+                tip->show();
+                tip->raise();
+                tip->adjustSize();
+
+                QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
+                pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
+                pos.ry() = pos.y() - 40;
+                tip->move(pos);
+            }
+        });
+    }
 
 protected:
     /**
@@ -82,22 +99,15 @@ protected:
         switch (event->type()) {
         case QEvent::ToolTip:
         case QEvent::Enter: {
-            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
-            auto tip = obj->property("HintWidget").value<Tip *>();
-            auto btn = tip->property("for").value<QWidget *>();
-            tip->setText(btn->toolTip());
-            tip->show();
-            tip->raise();
-            tip->adjustSize();
-
-            QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
-            pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
-            pos.ry() = pos.y() - 40;
-            tip->move(pos);
+            m_object = obj;
+            if (!m_showTime.isActive())
+                m_showTime.start(1000);
             return true;
         }
 
         case QEvent::Leave: {
+            m_object = nullptr;
+            m_showTime.stop();
             auto parent = obj->property("HintWidget").value<Tip *>();
             parent->hide();
             event->ignore();
@@ -114,6 +124,10 @@ protected:
         // standard event processing
         return QObject::eventFilter(obj, event);
     }
+
+private:
+    QTimer m_showTime;
+    QObject *m_object {nullptr};
 };
 /**
  * @brief The SliderTime class 进度条事件显示类
@@ -833,8 +847,6 @@ Platform_ToolboxProxy::Platform_ToolboxProxy(QWidget *mainWindow, PlayerEngine *
 
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
             this, &Platform_ToolboxProxy::updatePlayState);
-    connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
-            this, &Platform_ToolboxProxy::updateplaylisticon);
     connect(m_mircastWidget, &MircastWidget::updatePlayStatus, this, &Platform_ToolboxProxy::updatePlayState);
     connect(m_mircastWidget, &MircastWidget::updateTime, this, &Platform_ToolboxProxy::updateMircastTime, Qt::QueuedConnection);
 }
@@ -870,21 +882,6 @@ void Platform_ToolboxProxy::setthumbnailmode()
     updateMovieProgress();
 }
 
-void Platform_ToolboxProxy::updateplaylisticon()
-{
-    if (m_pListBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-        m_pListBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/episodes_checked.svg"));
-    } else {
-        m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
-    }
-
-    if (m_pMircastBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-        m_pMircastBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/mircast_chenked.svg"));
-    } else {
-        m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
-    }
-}
-
 void Platform_ToolboxProxy::setup()
 {
     QStackedLayout *stacked = new QStackedLayout(this);
@@ -1161,8 +1158,8 @@ void Platform_ToolboxProxy::setup()
         tr("Fullscreen"), tr("Miracast"), tr("Playlist")
     };
     QString attrs[] = {
-        tr("play"), tr("prev"), tr("next"),
-        tr("fs"), "mir", tr("list")
+        "play", "prev", "next",
+        "fs", "mir", "list"
     };
 
     for (unsigned int i = 0; i < sizeof(btns) / sizeof(btns[0]); i++) {
@@ -1547,10 +1544,11 @@ void Platform_ToolboxProxy::slotBaseMuteChanged(QString sk, const QVariant &/*va
 
 void Platform_ToolboxProxy::slotVolumeButtonClicked()
 {
-    if (m_pVolSlider->getsliderstate())
-        return;
     //与其他按键保持一致，工具栏隐藏时不响应
     if (!isVisible()) return;
+    m_pVolBtn->hideTip();
+    if (m_pVolSlider->getsliderstate())
+        return;
     /*
      * 设置-2为已经完成第一次打开设置音量
      * -1为初始化数值
@@ -1768,7 +1766,7 @@ void Platform_ToolboxProxy::hideMircastWidget()
 {
     m_mircastWidget->hide();
     m_pMircastBtn->setChecked(false);
-    updateplaylisticon();
+    m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
 }
 /**
  * @brief volumeUp 鼠标滚轮增加音量
@@ -2262,7 +2260,7 @@ void Platform_ToolboxProxy::buttonEnter()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         updateToolTipTheme(btn);
         btn->showToolTip();
     }
@@ -2275,7 +2273,7 @@ void Platform_ToolboxProxy::buttonLeave()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         btn->hideToolTip();
     }
 }
