@@ -385,10 +385,6 @@ public slots:
      * TODO(xxxpengfei)：此处窗口大小没用，请在1050前去除并梳理逻辑
      */
     void finishLoadSlot(QSize size);
-    /**
-     * @brief updateplaylisticon 切换主题时更新播放列表图标
-     */
-    void updateplaylisticon();
     /**
      * @brief setthumbnailmode 设置胶片进度条的模式
      */
