@@ -19,6 +19,8 @@
 #include "filefilter.h"
 
 //#include <QtWidgets>
+#include <QDir>
+
 #include <DImageButton>
 #include <DThemeManager>
 #include <DArrowRectangle>
@@ -118,7 +120,24 @@ public:
      * @brief TooltipHandler 构造函数
      * @param parent 父窗口
      */
-    explicit TooltipHandler(QObject *parent): QObject(parent) {}
+    explicit TooltipHandler(QObject *parent): QObject(parent) {
+        connect(&m_showTime, &QTimer::timeout, [=]{
+            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
+            if (m_object != nullptr) {
+                auto tip = m_object->property("HintWidget").value<Tip *>();
+                auto btn = tip->property("for").value<QWidget *>();
+                tip->setText(btn->toolTip());
+                tip->show();
+                tip->raise();
+                tip->adjustSize();
+
+                QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
+                pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
+                pos.ry() = pos.y() - 40;
+                tip->move(pos);
+            }
+        });
+    }
 
 protected:
     /**
@@ -132,22 +151,15 @@ protected:
         switch (event->type()) {
         case QEvent::ToolTip:
         case QEvent::Enter: {
-            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
-            auto tip = obj->property("HintWidget").value<Tip *>();
-            auto btn = tip->property("for").value<QWidget *>();
-            tip->setText(btn->toolTip());
-            tip->show();
-            tip->raise();
-            tip->adjustSize();
-
-            QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
-            pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
-            pos.ry() = pos.y() - 40;
-            tip->move(pos);
+            m_object = obj;
+            if (!m_showTime.isActive())
+                m_showTime.start(1000);
             return true;
         }
 
         case QEvent::Leave: {
+            m_object = nullptr;
+            m_showTime.stop();
             auto parent = obj->property("HintWidget").value<Tip *>();
             parent->hide();
             event->ignore();
@@ -164,6 +176,10 @@ protected:
         // standard event processing
         return QObject::eventFilter(obj, event);
     }
+
+private:
+    QTimer m_showTime;
+    QObject *m_object {nullptr};
 };
 /**
  * @brief The SliderTime class 进度条事件显示类
@@ -818,38 +834,87 @@ void viewProgBarLoad::loadViewProgBar(QSize size)
     auto url = m_pEngine->playlist().currentInfo().url;
     auto file = QFileInfo(url.toLocalFile()).absoluteFilePath();
 
-    for (auto i = 0; i < num ; i++) {
-        if (isInterruptionRequested()) {
-            qInfo() << "isInterruptionRequested";
-            return;
-        }
+    bool command = false;
+    if(m_pEngine->duration() < 300) {
+        QProcess process;
+        process.setProgram("ffmpeg");
+        QStringList options;
+        options << "-c" << QString("ffprobe -v quiet -show_frames %1 | grep \"pict_type=I\" | wc -l").arg(url.toLocalFile());
+        process.start("/bin/bash", options);
+        process.waitForFinished();
+        process.waitForReadyRead();
 
-        time = time.addMSecs(tmp);
-
-//        m_video_thumbnailer->seek_time = d.toString("hh:mm:ss").toLatin1().data();
-        memcpy(m_seekTime, time.toString("hh:mm:ss").toLatin1().data(), length + 1);
-        m_video_thumbnailer->seek_time = m_seekTime;
-        try {
-
-            m_mvideo_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, file.toUtf8().data(),  m_image_data);
-            auto img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
-            if (img.format() == QImage::Format_Invalid) {
-                return;
-            }
-            auto img_tmp = img.scaledToHeight(50);
-
-
-            pmList.append(QPixmap::fromImage(img_tmp.copy(img_tmp.size().width() / 2 - 4, 0, pixWidget, 50))); //-2 为了1px的内边框
-            QImage img_black = img_tmp.convertToFormat(QImage::Format_Grayscale8);
-            pmBlackList.append(QPixmap::fromImage(img_black.copy(img_black.size().width() / 2 - 4, 0, pixWidget, 50)));
-
-        } catch (const std::logic_error &) {
-
-        }
+        QString comStr = process.readAllStandardOutput();
+        QString str = comStr.trimmed();
+        int pictI = str.toInt();
+        if (pictI < 5)
+            command = true;
+        process.close();
     }
 
-    m_mvideo_thumbnailer_destroy_image_data(m_image_data);
-    m_image_data = nullptr;
+    if (command) {
+        QDir dir;
+        dir.mkpath("/tmp/Movie/");
+        dir.cd("/tmp/Movie/");
+
+        QProcess process;
+        process.setProgram("ffmpeg");
+        QStringList argList;
+        argList << "-i" << url.toLocalFile() << "-r" << QString("%1/%2").arg(num).arg(m_pEngine->duration()) << "-f" << "image2" << "/tmp/Movie/image-%05d.jpg";
+
+        process.setArguments(argList);
+        process.start();
+
+        process.waitForFinished();
+
+        dir.setFilter(QDir::AllEntries | QDir::NoDotAndDotDot); //设置过滤
+        QFileInfoList fileList = dir.entryInfoList(); // 获取所有的文件信息
+        foreach (QFileInfo fileInfo, fileList) {
+            if (fileInfo.isFile()) {
+                QImage img(fileInfo.absoluteFilePath());
+                auto img_tmp = img.scaledToHeight(50);
+
+                pmList.append(QPixmap::fromImage(img_tmp.copy(((img.width() * 50 / img.height()) - pixWidget) / 2, 0, pixWidget, 50))); //-2 为了1px的内边框
+                QImage img_black = img_tmp.convertToFormat(QImage::Format_Grayscale8);
+                pmBlackList.append(QPixmap::fromImage(img_black.copy(((img.width() * 50 / img.height()) - pixWidget) / 2, 0, pixWidget, 50)));
+            }
+        }
+
+        dir.removeRecursively();
+    } else {
+        for (auto i = 0; i < num ; i++) {
+            if (isInterruptionRequested()) {
+                qInfo() << "isInterruptionRequested";
+                return;
+            }
+
+            time = time.addMSecs(tmp);
+
+    //        m_video_thumbnailer->seek_time = d.toString("hh:mm:ss").toLatin1().data();
+            memcpy(m_seekTime, time.toString("hh:mm:ss").toLatin1().data(), length + 1);
+            m_video_thumbnailer->seek_time = m_seekTime;
+            try {
+
+                m_mvideo_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, file.toUtf8().data(),  m_image_data);
+                auto img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
+                if (img.format() == QImage::Format_Invalid) {
+                    return;
+                }
+                auto img_tmp = img.scaledToHeight(50);
+
+
+                pmList.append(QPixmap::fromImage(img_tmp.copy(img_tmp.size().width() / 2 - 4, 0, pixWidget, 50))); //-2 为了1px的内边框
+                QImage img_black = img_tmp.convertToFormat(QImage::Format_Grayscale8);
+                pmBlackList.append(QPixmap::fromImage(img_black.copy(img_black.size().width() / 2 - 4, 0, pixWidget, 50)));
+
+            } catch (const std::logic_error &) {
+
+            }
+        }
+
+        m_mvideo_thumbnailer_destroy_image_data(m_image_data);
+        m_image_data = nullptr;
+    }
 
     m_pListPixmapMutex->lock();
     m_pParent->addpmList(pmList);
@@ -884,8 +949,6 @@ ToolboxProxy::ToolboxProxy(QWidget *mainWindow, PlayerEngine *proxy)
 
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
             this, &ToolboxProxy::updatePlayState);
-    connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
-            this, &ToolboxProxy::updateplaylisticon);
     connect(m_mircastWidget, &MircastWidget::updatePlayStatus, this, &ToolboxProxy::updatePlayState);
     connect(m_mircastWidget, &MircastWidget::updateTime, this, &ToolboxProxy::updateMircastTime, Qt::QueuedConnection);
 }
@@ -933,21 +996,6 @@ void ToolboxProxy::setthumbnailmode()
 
 }
 
-void ToolboxProxy::updateplaylisticon()
-{
-    if (m_pListBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-        m_pListBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/episodes_checked.svg"));
-    } else {
-        m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
-    }
-
-    if (m_pMircastBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-        m_pMircastBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/mircast_chenked.svg"));
-    } else {
-        m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
-    }
-}
-
 void ToolboxProxy::setup()
 {
     QStackedLayout *stacked = new QStackedLayout(this);
@@ -1234,8 +1282,8 @@ void ToolboxProxy::setup()
             tr("Fullscreen"), tr("Miracast"), tr("Playlist")
         };
         QString attrs[] = {
-            tr("play"), tr("prev"), tr("next"),
-            tr("fs"), "mir", tr("list")
+            "play", "prev", "next",
+            "fs", "mir", "list"
         };
 
         for (unsigned int i = 0; i < sizeof(btns) / sizeof(btns[0]); i++) {
@@ -1621,10 +1669,11 @@ void ToolboxProxy::slotBaseMuteChanged(QString sk, const QVariant &/*val*/)
 
 void ToolboxProxy::slotVolumeButtonClicked()
 {
-    if (m_pVolSlider->getsliderstate())
-        return;
     //与其他按键保持一致，工具栏隐藏时不响应
     if (!isVisible()) return;
+    m_pVolBtn->hideTip();
+    if (m_pVolSlider->getsliderstate())
+        return;
     /*
      * 设置-2为已经完成第一次打开设置音量
      * -1为初始化数值
@@ -1883,7 +1932,7 @@ void ToolboxProxy::hideMircastWidget()
 {
     m_mircastWidget->hide();
     m_pMircastBtn->setChecked(false);
-    updateplaylisticon();
+    m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
 }
 /**
  * @brief volumeUp 鼠标滚轮增加音量
@@ -2395,7 +2444,7 @@ void ToolboxProxy::buttonEnter()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         updateToolTipTheme(btn);
         btn->showToolTip();
     }
@@ -2408,7 +2457,7 @@ void ToolboxProxy::buttonLeave()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         btn->hideToolTip();
     }
 }
