@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sv">
+<TS version="2.1" language="sv">
 <context>
     <name>MircastShowWidget</name>
     <message>
@@ -688,19 +688,19 @@ Please do not exit the Movie app during the process.</source>
     <name>dmr::MovieInfo</name>
     <message>
         <source>%1G</source>
-        <translation>%1G</translation>
+        <translation type="vanished">%1G</translation>
     </message>
     <message>
         <source>%1M</source>
-        <translation>%1M</translation>
+        <translation type="vanished">%1M</translation>
     </message>
     <message>
         <source>%1K</source>
-        <translation>%1K</translation>
+        <translation type="vanished">%1K</translation>
     </message>
     <message>
         <source>%1</source>
-        <translation>%1</translation>
+        <translation type="vanished">%1</translation>
     </message>
 </context>
 <context>
@@ -1037,26 +1037,6 @@ Please do not exit the Movie app during the process.</source>
         <source>Playlist</source>
         <translation type="unfinished">Spellista</translation>
     </message>
-    <message>
-        <source>play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>prev</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>next</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>fs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>list</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Exit fullscreen</source>
         <translation type="unfinished">Stäng fullskärm</translation>
@@ -1069,10 +1049,6 @@ Please do not exit the Movie app during the process.</source>
         <source>Play</source>
         <translation type="unfinished">Spela</translation>
     </message>
-    <message>
-        <source>sub</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Miracast</source>
         <translation type="unfinished"></translation>
@@ -1165,26 +1141,6 @@ Please do not exit the Movie app during the process.</source>
         <source>Play/Pause</source>
         <translation>Spela/Pausa</translation>
     </message>
-    <message>
-        <source>play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>prev</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>next</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>fs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>list</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Exit fullscreen</source>
         <translation>Stäng fullskärm</translation>
@@ -1193,13 +1149,16 @@ Please do not exit the Movie app during the process.</source>
         <source>Pause</source>
         <translation>Pausa</translation>
     </message>
-    <message>
-        <source>sub</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Miracast</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>dmr::VolumeButton</name>
+    <message>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
